<?php
/**
 * Plugin Name: ShieldCraft Secure
 * Plugin URI: https://royalservicesagency.com/secure
 * Description: Enhances website security with vulnerability checking and 2FA. Upgrade for full features.
 * Version: 1.0.0
 * Author: Royal Services Agency
 * Author URI: https://royalservicesagency.com
 * License: GPL-2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain: shieldcraft-secure
 * Domain Path: /languages
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

// Define plugin constants
define('SHIELDCRAFT_SECURE_VERSION', '1.0.0');
define('SHIELDCRAFT_SECURE_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('SHIELDCRAFT_SECURE_PLUGIN_URL', plugin_dir_url(__FILE__));

// Include necessary files
require_once SHIELDCRAFT_SECURE_PLUGIN_DIR . 'includes/functions.php';
require_once SHIELDCRAFT_SECURE_PLUGIN_DIR . 'includes/admin-pages.php';
require_once SHIELDCRAFT_SECURE_PLUGIN_DIR . 'includes/pages/vulnerability-checks.php';
require_once SHIELDCRAFT_SECURE_PLUGIN_DIR . 'includes/pages/2fa-authentication.php';

// Include the Composer autoloader
require_once plugin_dir_path(__FILE__) . 'vendor/autoload.php';

// Initialize the plugin
function shieldcraft_secure_init() {
    // Load plugin text domain for translations
    load_plugin_textdomain('shieldcraft-secure', false, dirname(plugin_basename(__FILE__)) . '/languages/');
    shieldcraft_secure_load_textdomain();
    // Register admin pages
    add_action('admin_menu', 'shieldcraft_secure_register_admin_pages');
    add_action('admin_enqueue_scripts', 'shieldcraft_secure_enqueue_assets');
}
add_action('plugins_loaded', 'shieldcraft_secure_init');

function shieldcraft_secure_load_textdomain() {
    $language = get_option('shieldcraft_secure_language', 'en_US');
    $mo_file = SHIELDCRAFT_SECURE_PLUGIN_DIR . 'includes/languages/' . $language . '/shieldcraft-secure-' . $language . '.mo';
    
    if (file_exists($mo_file)) {
        load_textdomain('shieldcraft-secure', $mo_file);
    } else {
        load_plugin_textdomain('shieldcraft-secure', false, dirname(plugin_basename(__FILE__)) . '/includes/languages/' . $language);
    }
    
    if (defined('WP_DEBUG') && WP_DEBUG) {
        error_log("ShieldCraft Secure: Attempting to load language file: " . $mo_file);
        error_log("ShieldCraft Secure: Current language setting: " . $language);
    }
}
add_action('plugins_loaded', 'shieldcraft_secure_load_textdomain');

// Check if user has the paid version
function shieldcraft_secure_is_paid_version() {
    // Implement your license checking logic here
    return false; // Return true for paid version, false for free version
}

// Display purchase message for premium features
function shieldcraft_secure_display_purchase_message() {
    echo '<div class="notice notice-info"><p>' . __('This feature is only available in the paid version of ShieldCraft Secure. <a href="https://royalservicesagency.com/secure-upgrade" target="_blank">Upgrade now</a> to access all premium features!', 'shieldcraft-secure') . '</p></div>';
}

// Schedule vulnerability checks
function shieldcraft_secure_schedule_checks() {
    if (!wp_next_scheduled('shieldcraft_secure_check_vulnerabilities')) {
        wp_schedule_event(time(), 'daily', 'shieldcraft_secure_check_vulnerabilities');
    }
}
register_activation_hook(__FILE__, 'shieldcraft_secure_schedule_checks');

// Clear scheduled events on plugin deactivation
function shieldcraft_secure_deactivate() {
    wp_clear_scheduled_hook('shieldcraft_secure_check_vulnerabilities');
}
register_deactivation_hook(__FILE__, 'shieldcraft_secure_deactivate');

// Run vulnerability checks
add_action('shieldcraft_secure_check_vulnerabilities', 'shieldcraft_secure_check_vulnerabilities');