(function ($) {
    'use strict';

    document.addEventListener('DOMContentLoaded', function() {
        var cards = document.querySelectorAll('.shieldcraft-secure-card');

        cards.forEach(function(card) {
            var header = card.querySelector('.shieldcraft-secure-card-header');

            header.addEventListener('click', function() {
                card.classList.toggle('active');
            });
        });

        // Malware scanner
        var scanButton = document.getElementById('shieldcraft-secure-scan-now');
        var scanStatusElement = document.getElementById('shieldcraft-secure-scan-status');
        var scanCurrentFileElement = document.getElementById('shieldcraft-secure-scan-current-file');
        var infectedFilesContainer = document.getElementById('shieldcraft-secure-infected-files-container');
        var infectedFilesTable = document.getElementById('shieldcraft-secure-infected-files-table').getElementsByTagName('tbody')[0];

        scanButton.addEventListener('click', function() {
            scanButton.disabled = true;
            scanStatusElement.innerHTML = '';
            scanCurrentFileElement.innerHTML = '';
            document.getElementById('shieldcraft-secure-scanning-animation').classList.add('active');

            var xhr = new XMLHttpRequest();
            var scanResults = [];

            xhr.onreadystatechange = function() {
                if (xhr.readyState === XMLHttpRequest.DONE) {
                    document.getElementById('shieldcraft-secure-scanning-animation').classList.remove('active');
                    scanButton.disabled = false;
                    console.log('Raw response:', xhr.responseText); // Log the raw response
                    try {
                        var responseText = xhr.responseText.trim();
                        if (responseText) {
                            var lines = responseText.split('\n');
                            lines.forEach(function(line) {
                                if (line.startsWith('scan_result:')) {
                                    var result = JSON.parse(line.slice(12));
                                    scanResults.push(result);
                                }
                            });
                            displayInfectedFiles(scanResults);
                            scanCurrentFileElement.innerHTML = 'Scan completed.';
                        } else {
                            throw new Error("Invalid JSON response");
                        }
                    } catch (e) {
                        console.error('Error parsing JSON:', e);
                        scanCurrentFileElement.innerHTML = 'An error occurred during the scan.';
                    }
                }
            };

            xhr.onprogress = function(event) {
                var response = event.target.responseText;
                var lines = response.split('\n');
                var lastLine = lines[lines.length - 2];

                if (lastLine && lastLine.startsWith('scan_result:')) {
                    var result = JSON.parse(lastLine.slice(12));
                    var statusClass = result.status === 'Clean' ? 'shieldcraft-secure-status-clean' : 'shieldcraft-secure-status-infected';
                    scanCurrentFileElement.innerHTML = result.file + ': <span class="' + statusClass + '">' + result.status + '</span>';
                }
            };

            function displayInfectedFiles(scanResults) {
                infectedFilesTable.innerHTML = '';

                var infectedFiles = scanResults.filter(function(result) {
                    return result.status === 'Infected';
                });

                if (infectedFiles.length > 0) {
                    infectedFiles.forEach(function(file) {
                        var row = infectedFilesTable.insertRow();
                        var fileNameCell = row.insertCell();
                        var locationCell = row.insertCell();
                        var statusCell = row.insertCell();
                        var issueCell = row.insertCell();
                        var patternCell = row.insertCell(); // New cell for the suspicious pattern

                        fileNameCell.innerHTML = file.file;
                        locationCell.innerHTML = file.location;
                        statusCell.innerHTML = '<span class="shieldcraft-secure-status-infected">' + file.status + '</span>';
                        issueCell.innerHTML = file.issue;
                        patternCell.innerHTML = file.pattern; // Display the suspicious pattern
                    });

                    infectedFilesContainer.style.display = 'block';
                } else {
                    infectedFilesContainer.style.display = 'none';
                }
            }

            xhr.open('POST', ajaxurl, true);
            xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded;');
            xhr.send('action=shieldcraft_secure_malware_scan&nonce=' + shieldcraft_secure_params.nonce);
        });
    });

})(jQuery);
