<?php
// Render the 2FA authentication page
function shieldcraft_secure_render_2fa_authentication_page() {
    // Check if the PHPGangsta/GoogleAuthenticator library is available
    if (!class_exists('PHPGangsta_GoogleAuthenticator')) {
        echo '<p>' . __('The PHPGangsta/GoogleAuthenticator library is not installed. Please install it using Composer.', 'shieldcraft-secure') . '</p>';
        return;
    }

    $user_id = get_current_user_id();
    $ga = new PHPGangsta_GoogleAuthenticator();

    // Check if 2FA is already enabled for the user
    $secret = get_user_meta($user_id, 'shieldcraft_secure_2fa_secret', true);

    if (empty($secret)) {
        // Generate a new 2FA secret
        $secret = $ga->createSecret();
        update_user_meta($user_id, 'shieldcraft_secure_2fa_secret', $secret);
    }

    // Generate the QR code URL
    $qr_code_url = $ga->getQRCodeGoogleUrl(get_bloginfo('name'), $secret);
    
    // Generate recovery codes
    $recovery_codes = shieldcraft_secure_generate_recovery_codes($user_id);
    ?>
 <div class="wrap shieldcraft-secure-wrap">
        <div class="shieldcraft-secure-title"><h2><?php _e('Two-Factor Authentication', 'shieldcraft-secure'); ?></h2></div>
        <p><?php _e('Enhance the security of your account by enabling two-factor authentication.', 'shieldcraft-secure'); ?></p>
    <?php
    // Check if 2FA is already enabled for the user
    $is_2fa_enabled = get_user_meta($user_id, 'shieldcraft_secure_2fa_enabled', true);

    if ($is_2fa_enabled) {
        echo '<div class="notice notice-success"><p>' . sprintf(__('Two-factor authentication is already enabled for user %s.', 'shieldcraft-secure'), esc_html(wp_get_current_user()->user_login)) . '</p></div>';
    }
    ?>
  <div class="shieldcraft-secure-2fa-container">
            <div class="shieldcraft-secure-2fa-box">
                <div class="shieldcraft-secure-title"><h2><?php _e('1. Scan Code or Enter Key', 'shieldcraft-secure'); ?></h2></div>
            <p><?php _e('Scan the code below with your authenticator app to add this account. Some authenticator apps also allow you to type in the text version instead.', 'shieldcraft-secure'); ?></p>
            <div class="shieldcraft-secure-2fa-qr-code">
                <img src="<?php echo esc_url($qr_code_url); ?>" alt="2FA QR Code">
            </div>
            <p><strong><?php _e('Secret Key:', 'shieldcraft-secure'); ?></strong> <code><?php echo esc_html($secret); ?></code></p>
        </div>
<?php if ($is_2fa_enabled) : ?>
    <div class="shieldcraft-secure-2fa-disable">
        <button id="shieldcraft-secure-2fa-disable" class="button button-secondary"><?php _e('Disable Two-Factor Authentication', 'shieldcraft-secure'); ?></button>
    </div>
<?php endif; ?>
  <div class="shieldcraft-secure-2fa-box">
                <div class="shieldcraft-secure-title"><h2><?php _e('2. Enter Code from Authenticator App', 'shieldcraft-secure'); ?></h2></div>
            <p><?php _e('Download Recovery Codes (Optional)', 'shieldcraft-secure'); ?></p>
            <p><?php _e('Use one of these 5 codes to log in if you lose access to your authenticator device. Codes are 16 characters long plus optional spaces. Each one may be used only once.', 'shieldcraft-secure'); ?></p>
            <ul class="shieldcraft-secure-2fa-recovery-codes">
                <?php foreach ($recovery_codes as $code) : ?>
                    <li><code><?php echo esc_html($code); ?></code></li>
                <?php endforeach; ?>
            </ul>
            <a href="<?php echo admin_url('admin-post.php?action=download_recovery_codes'); ?>" class="button button-secondary">Download</a>
            <p><?php _e('Enter the code from your authenticator app below to verify and activate two-factor authentication for this account.', 'shieldcraft-secure'); ?></p>
            <div class="shieldcraft-secure-2fa-activation">
                <input type="text" id="shieldcraft-secure-2fa-code" name="shieldcraft-secure-2fa-code" placeholder="<?php _e('123456', 'shieldcraft-secure'); ?>">
                <button id="shieldcraft-secure-2fa-activate" class="button button-primary"><?php _e('Activate', 'shieldcraft-secure'); ?></button>
            </div>
            <p><a href="<?php echo esc_url('#'); ?>"><?php _e('For help on setting up an app, visit our help article.', 'shieldcraft-secure'); ?></a></p>
        </div>
    </div>
</div>
    <?php
}

// Generate recovery codes for the user
function shieldcraft_secure_generate_recovery_codes($user_id) {
    $recovery_codes = array();
    
    for ($i = 0; $i < 5; $i++) {
        $code_parts = array();
        for ($j = 0; $j < 4; $j++) {
            $code_parts[] = wp_generate_password(4, false, false);
        }
        $recovery_codes[] = implode(' ', $code_parts);
    }
    
    update_user_meta($user_id, 'shieldcraft_secure_2fa_recovery_codes', $recovery_codes);
    
    return $recovery_codes;
}

// Generate download URL for recovery codes
function shieldcraft_secure_generate_recovery_codes_download_url($user_id) {
    $recovery_codes = get_user_meta($user_id, 'shieldcraft_secure_2fa_recovery_codes', true);

    // Extract the recovery codes from the HTML using regular expression
    $recovery_codes_text = implode("\n", $recovery_codes);

    // Generate the download URL
    $url = 'data:text/plain;charset=utf-8,' . rawurlencode($recovery_codes_text);
    return $url;
}

function shieldcraft_secure_download_recovery_codes() {
    $user_id = get_current_user_id();
    $recovery_codes = get_user_meta($user_id, 'shieldcraft_secure_2fa_recovery_codes', true);

    if (!empty($recovery_codes)) {
        header('Content-Type: text/plain');
        header('Content-Disposition: attachment; filename="recovery-codes.txt"');
        
        echo implode("\n", $recovery_codes);
        exit;
    } else {
        wp_die('No recovery codes to download.');
    }
}

add_action('admin_post_download_recovery_codes', 'shieldcraft_secure_download_recovery_codes');


// Handle 2FA activation
function shieldcraft_secure_activate_2fa() {
    check_ajax_referer('shieldcraft_secure_2fa_nonce', 'nonce');

    $user_id = get_current_user_id();
    $secret = get_user_meta($user_id, 'shieldcraft_secure_2fa_secret', true);
    $entered_code = sanitize_text_field($_POST['code']);

    $ga = new PHPGangsta_GoogleAuthenticator();
    $valid = $ga->verifyCode($secret, $entered_code);

    if ($valid) {
        update_user_meta($user_id, 'shieldcraft_secure_2fa_enabled', true);
        wp_send_json_success(__('Two-factor authentication has been enabled.', 'shieldcraft-secure'));
    } else {
        wp_send_json_error(__('Invalid code. Please try again.', 'shieldcraft-secure'));
    }
}
add_action('wp_ajax_shieldcraft_secure_activate_2fa', 'shieldcraft_secure_activate_2fa');

// Handle 2FA disable
function shieldcraft_secure_disable_2fa() {
    check_ajax_referer('shieldcraft_secure_2fa_nonce', 'nonce');

    $user_id = get_current_user_id();
    delete_user_meta($user_id, 'shieldcraft_secure_2fa_enabled');
    delete_user_meta($user_id, 'shieldcraft_secure_2fa_secret');
    delete_user_meta($user_id, 'shieldcraft_secure_2fa_recovery_codes');

    wp_send_json_success(array(
    'message' => __('Two-factor authentication has been disabled.', 'shieldcraft-secure'),
    'reload' => true,
));
}
add_action('wp_ajax_shieldcraft_secure_disable_2fa', 'shieldcraft_secure_disable_2fa');

// Enqueue 2FA authentication scripts
function shieldcraft_secure_enqueue_2fa_scripts($hook) {
    if ('shieldcraft-secure_page_shieldcraft-secure-2fa' !== $hook) {
        return;
    }

    wp_enqueue_script('shieldcraft-secure-2fa-script', SHIELDCRAFT_SECURE_PLUGIN_URL . 'includes/js/2fa-script.js', array('jquery'), SHIELDCRAFT_SECURE_VERSION, true);
    wp_localize_script('shieldcraft-secure-2fa-script', 'shieldcraftSecure2FA', array(
        'ajaxUrl' => admin_url('admin-ajax.php'),
        'nonce' => wp_create_nonce('shieldcraft_secure_2fa_nonce'),
    ));
}
add_action('admin_enqueue_scripts', 'shieldcraft_secure_enqueue_2fa_scripts');