<?php

function shieldcraft_secure_get_public_ip() {
    $public_ip = '';

    $response = wp_remote_get('https://api.ipify.org');

    if (!is_wp_error($response) && wp_remote_retrieve_response_code($response) === 200) {
        $public_ip = wp_remote_retrieve_body($response);
    }

    return $public_ip;
}
function shieldcraft_secure_is_htaccess_writable() {
    $htaccess_path = ABSPATH . '.htaccess';

    if (file_exists($htaccess_path)) {
        $permissions = fileperms($htaccess_path);
        return ($permissions & 0x0002) ? true : false;
    }

    return false;
}
function shieldcraft_secure_render_extras_page() {
    ?>
    <div class="wrap shieldcraft-secure-wrap">
    <div class="shieldcraft-secure-header">
        <h1><?php _e('Extras', 'shieldcraft-secure'); ?></h1>
    </div>
    
    <form method="post" action="options.php">
            <?php settings_fields('shieldcraft_secure_extras_group'); ?>
            <?php do_settings_sections('shieldcraft_secure_extras_group'); ?>
            
            <table class="form-table">
                <tr valign="top">
                    <th scope="row"><?php _e('Rename Login URL', 'shieldcraft-secure'); ?></th>
                    <td>
                        <input type="text" name="shieldcraft_secure_admin_url" value="<?php echo esc_attr(get_option('shieldcraft_secure_admin_url')); ?>" class="regular-text shieldcraft-secure-field">
                        <p class="description"><?php _e('Enter a new name for the Login URL. Leave empty to use the default URL.', 'shieldcraft-secure'); ?></p>
                    </td>
                </tr>
            <tr valign="top">
                <th scope="row"><?php _e('Disable Admin Registration', 'shieldcraft-secure'); ?></th>
                <td>
                    <label>
                        <input type="checkbox" name="shieldcraft_secure_disable_admin_reg" value="1" <?php checked(1, get_option('shieldcraft_secure_disable_admin_reg'), true); ?>>
                        <?php _e('Prevent users from registering with admin usernames', 'shieldcraft-secure'); ?>
                    </label>
                </td>
            </tr>
        </table>
        
        <h2><?php _e('System Information', 'shieldcraft-secure'); ?></h2>
        <table class="widefat shieldcraft-secure-table">
            <tbody>
                <tr>
                    <td><?php _e('WordPress Version', 'shieldcraft-secure'); ?></td>
                    <td><?php echo esc_html(get_bloginfo('version')); ?></td>
                </tr>
                <tr>
                    <td><?php _e('Public IP', 'shieldcraft-secure'); ?></td>
                    <td><?php echo esc_html(shieldcraft_secure_get_public_ip()); ?></td>
                </tr>
                <tr>
                    <td><?php _e('PHP Version', 'shieldcraft-secure'); ?></td>
                    <td><?php echo esc_html(phpversion()); ?></td>
                </tr>
                <tr>
                    <td><?php _e('Temp Directory Writable', 'shieldcraft-secure'); ?></td>
                    <td>
                        <?php echo is_writable(sys_get_temp_dir()) ? '<span class="status-icon green"></span>' . __('Yes', 'shieldcraft-secure') : '<span class="status-icon red"></span>' . __('No', 'shieldcraft-secure'); ?>
                    </td>
                </tr>
                <tr>
                    <td><?php _e('Uploads Directory Writable', 'shieldcraft-secure'); ?></td>
                    <td>
                        <?php echo is_writable(wp_upload_dir()['basedir']) ? '<span class="status-icon green"></span>' . __('Yes', 'shieldcraft-secure') : '<span class="status-icon red"></span>' . __('No', 'shieldcraft-secure'); ?>
                    </td>
                </tr>
                <tr>
                    <td><?php _e('.htaccess Writable by Others', 'shieldcraft-secure'); ?></td>
                    <td>
                        <?php echo shieldcraft_secure_is_htaccess_writable() ? '<span class="status-icon red"></span>' . __('Yes', 'shieldcraft-secure') : '<span class="status-icon green"></span>' . __('No', 'shieldcraft-secure'); ?>
                    </td>
                </tr>
            </tbody>
        </table>
        <p></p>
      <input type="submit" class="button button-primary shieldcraft-secure-button" value="<?php _e('Save Changes', 'shieldcraft-secure'); ?>">
    </form>
</div>
    <?php
}