<?php
// Render settings page
function shieldcraft_secure_render_settings_page() {
    ?>
    <div class="wrap shieldcraft-secure-wrap">
        <div class="shieldcraft-secure-header">
        <h1><?php _e('Settings', 'shieldcraft-secure'); ?></h1>
    </div>
        <form method="post" action="options.php">
            <?php settings_fields('shieldcraft_secure_settings_group'); ?>
            <?php do_settings_sections('shieldcraft_secure_settings_group'); ?>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row"><?php _e('Language', 'shieldcraft-secure'); ?></th>
                    <td>
                        <select name="shieldcraft_secure_language" class="shieldcraft-secure-field">
                            <option value="en_US" <?php selected(get_option('shieldcraft_secure_language'), 'en_US'); ?>><?php _e('English (United States)', 'shieldcraft-secure'); ?></option>
                            <option value="hr_HR" <?php selected(get_option('shieldcraft_secure_language'), 'hr_HR'); ?>><?php _e('Croatian', 'shieldcraft-secure'); ?></option>
                            <option value="sl_SI" <?php selected(get_option('shieldcraft_secure_language'), 'sl_SI'); ?>><?php _e('Slovenian', 'shieldcraft-secure'); ?></option>
                            <option value="de_DE" <?php selected(get_option('shieldcraft_secure_language'), 'de_DE'); ?>><?php _e('German', 'shieldcraft-secure'); ?></option>
                        </select>
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row"><?php _e('Vulnerability Check Frequency', 'shieldcraft-secure'); ?></th>
                    <td>
                          <select name="shieldcraft_secure_check_frequency" class="shieldcraft-secure-field">
                              <option value="every_5_minutes" <?php selected(get_option('shieldcraft_secure_check_frequency'), 'every_5_minutes'); ?>><?php _e('Every 5 Minutes', 'shieldcraft-secure'); ?></option>
                            <option value="daily" <?php selected(get_option('shieldcraft_secure_check_frequency'), 'daily'); ?>><?php _e('Daily', 'shieldcraft-secure'); ?></option>
                            <option value="weekly" <?php selected(get_option('shieldcraft_secure_check_frequency'), 'weekly'); ?>><?php _e('Weekly', 'shieldcraft-secure'); ?></option>
                            <option value="biweekly" <?php selected(get_option('shieldcraft_secure_check_frequency'), 'biweekly'); ?>><?php _e('Every 2 Weeks', 'shieldcraft-secure'); ?></option>
                            <option value="monthly" <?php selected(get_option('shieldcraft_secure_check_frequency'), 'monthly'); ?>><?php _e('Monthly', 'shieldcraft-secure'); ?></option>
                        </select>
                    </td>
                </tr>
                <tr valign="top">
                <th scope="row"><?php _e('Notification Email', 'shieldcraft-secure'); ?></th>
                <td>
                    <input type="email" name="shieldcraft_secure_notification_email" value="<?php echo esc_attr(get_option('shieldcraft_secure_notification_email', get_option('admin_email'))); ?>" class="regular-text">
                    <p class="description"><?php _e('Enter the email address where vulnerability alerts should be sent.', 'shieldcraft-secure'); ?></p>
                </td>
            </tr>
            </table>
            <?php submit_button(__('Save Changes', 'shieldcraft-secure'), 'primary shieldcraft-secure-button', 'submit', false); ?>
        </form>
    </div>
    <?php
}

// Register settings
function shieldcraft_secure_register_settings() {
    register_setting('shieldcraft_secure_settings_group', 'shieldcraft_secure_language', 'shieldcraft_secure_language_sanitize');
    register_setting('shieldcraft_secure_settings_group', 'shieldcraft_secure_check_frequency');
    register_setting('shieldcraft_secure_settings_group', 'shieldcraft_secure_notification_email');
    register_setting('shieldcraft_secure_extras_group', 'shieldcraft_secure_admin_url');
    register_setting('shieldcraft_secure_extras_group', 'shieldcraft_secure_disable_admin_reg');
    add_action('update_option_shieldcraft_secure_check_frequency', 'shieldcraft_secure_update_check_frequency', 10, 3);
    add_filter('cron_schedules', 'shieldcraft_secure_add_cron_intervals');
}
add_action('admin_init', 'shieldcraft_secure_register_settings');

function shieldcraft_secure_language_sanitize($input) {
    $old_value = get_option('shieldcraft_secure_language');
    if ($old_value !== $input) {
        // Language has changed, reload text domain
        $mo_file = SHIELDCRAFT_SECURE_PLUGIN_DIR . 'includes/languages/' . $input . '/shieldcraft-secure-' . $input . '.mo';
        unload_textdomain('shieldcraft-secure');
        load_textdomain('shieldcraft-secure', $mo_file);
        
        if (defined('WP_DEBUG') && WP_DEBUG) {
            error_log("ShieldCraft Secure: Language changed from $old_value to $input");
            error_log("ShieldCraft Secure: Attempting to load language file: $mo_file");
        }
    }
    return $input;
}


function shieldcraft_secure_add_cron_intervals($schedules) {
    $schedules['every_5_minutes'] = array(
        'interval' => 5 * 60, // 5 minutes in seconds
        'display'  => __('Every 5 Minutes', 'shieldcraft-secure'),
    );
    return $schedules;
}

function shieldcraft_secure_update_check_frequency($old_value, $new_value, $option_name) {
    if ($old_value !== $new_value) {
        // Clear the existing scheduled event
        wp_clear_scheduled_hook('shieldcraft_secure_check_vulnerabilities');
        error_log('ShieldCraft Secure: Cleared scheduled vulnerability checks due to frequency change.');

        // Schedule the event with the new frequency
        wp_schedule_event(time(), $new_value, 'shieldcraft_secure_check_vulnerabilities');
        error_log('ShieldCraft Secure: Rescheduled vulnerability checks with new frequency: ' . $new_value);
    }
}

// Add this function to reload text domain after settings are saved
function shieldcraft_secure_after_save_settings() {
    $language = get_option('shieldcraft_secure_language', 'en_US');
    $mo_file = SHIELDCRAFT_SECURE_PLUGIN_DIR . 'includes/languages/' . $language . '/shieldcraft-secure-' . $language . '.mo';
    unload_textdomain('shieldcraft-secure');
    load_textdomain('shieldcraft-secure', $mo_file);
    
    if (defined('WP_DEBUG') && WP_DEBUG) {
        error_log("ShieldCraft Secure: Reloaded text domain after saving settings");
        error_log("ShieldCraft Secure: Current language setting: $language");
        error_log("ShieldCraft Secure: Loaded language file: $mo_file");
    }
}
add_action('update_option_shieldcraft_secure_language', 'shieldcraft_secure_after_save_settings');